Crate bunsen_cache

Crate bunsen_cache 

Structs

DiskCacheConfig
Cache Policy
PreFabConfig
A Config Well-Known Pre-Fab.
PreFabMap
A map of PreFabConfigs.
PretrainedWeightsDescriptor
A descriptor for a pretrained weights file.
PretrainedWeightsMap
Directory of PretrainedWeightsDescriptors.
StaticPreFabConfig
Static builder for a PreFabConfig
StaticPreFabMap
Static builder for a PreFabMap.
StaticPretrainedWeightsDescriptor
Static PretrainedWeightsDescriptor provider.
StaticPretrainedWeightsMap
Static PretrainedWeightsMap builder.

Functions

fetch_model_weights
Returns a local path to model weights file. If the file does not exist, it will be downloaded from the given URL.
pretrained_weights_resource_key
Get the cache resource key for a pretrained weights file.
try_cache_download_to_path
Download a URL resource to a given path.
url_to_cache_key
Build a cache key (bare cache file name) from a name and URL.