pub struct DiskCacheConfig {
pub root_cache_key: String,
}Expand description
Cache Policy
Fields
root_cache_key: StringKey for the root cache directory.
Implementations
Sourceimpl DiskCacheConfig
impl DiskCacheConfig
Sourcepub fn with_root_cache_key(self, root_cache_key: String) -> Self
pub fn with_root_cache_key(self, root_cache_key: String) -> Self
Sets the value for the field root_cache_key.
Key for the root cache directory.
- Defaults to
"\"bimm\".to_string()"
Sourceimpl DiskCacheConfig
impl DiskCacheConfig
Sourcepub fn base_cache_dir(&self) -> Result<PathBuf>
pub fn base_cache_dir(&self) -> Result<PathBuf>
Fetch the base cache directory.
If the cache directory does not exist, does not create it.
Sourcepub fn ensure_base_cache_dir(&self) -> Result<PathBuf>
pub fn ensure_base_cache_dir(&self) -> Result<PathBuf>
Fetch the base cache directory.
If the cache directory does not exist, creates it.
Sourcepub fn resource_to_path(&self, resource_key: &[String]) -> Result<PathBuf>
pub fn resource_to_path(&self, resource_key: &[String]) -> Result<PathBuf>
Map a resource key to a cache path.
Does not ensure that the path (or any of the parents) exist.
Sourcepub fn ensure_resource_parent_dir(
&self,
resource_key: &[String],
) -> Result<PathBuf>
pub fn ensure_resource_parent_dir( &self, resource_key: &[String], ) -> Result<PathBuf>
Map a resource key to a cache path and ensure the parent directory exists.